// src/index.ts
import { createRequire } from "module";
import { createSyncFn } from "synckit";
var ExtraPosition = /* @__PURE__ */ ((ExtraPosition2) => {
  ExtraPosition2[ExtraPosition2["before"] = 0] = "before";
  ExtraPosition2[ExtraPosition2["after"] = 1] = "after";
  return ExtraPosition2;
})(ExtraPosition || {});
function getThemeName(theme) {
  if (typeof theme === "string")
    return theme;
  return theme.name;
}
var HIGHLIGHT_RE = /{([\d,-]+)}/;
var BACKGROUND_STYLE_RE = /^<pre[^>]*style="([^"]*)"[^>]*>/;
var EXTRACT_STYLE_RE = /^(<[a-zA-z\-]+[^>]+)(style=")([^"]*)("[^>]*>)/;
var EXTRACT_CLASS_RE = /^(<[a-zA-z\-]+[^>]+)(class=")([^"]*)("[^>]*>)/;
var NO_EXTRACT_RE = /^(<[a-zA-z\-]+[^>]*)(>)/;
var DARK_CLASS = "shiki-dark";
var LIGHT_CLASS = "shiki-light";
function resolveOptions(options) {
  const themes = [];
  let darkModeThemes;
  if (!options.theme) {
    themes.push("nord");
  } else if (typeof options.theme === "string") {
    themes.push(options.theme);
  } else {
    if ("dark" in options.theme || "light" in options.theme) {
      darkModeThemes = options.theme;
      themes.push(darkModeThemes.dark);
      themes.push(darkModeThemes.light);
    } else {
      themes.push(options.theme);
    }
  }
  return {
    ...options,
    themes,
    darkModeThemes: darkModeThemes ? {
      dark: getThemeName(darkModeThemes.dark),
      light: getThemeName(darkModeThemes.light)
    } : void 0,
    extra: options.extra || []
  };
}
var attrsToLines = (attrs) => {
  const result = [];
  if (!attrs.trim())
    return [];
  attrs.split(",").map((v) => v.split("-").map((v2) => parseInt(v2, 10))).forEach(([start, end]) => {
    if (start && end) {
      result.push(
        ...Array.from({ length: end - start + 1 }, (_, i) => start + i)
      );
    } else {
      result.push(start);
    }
  });
  return result.map((v) => ({
    line: v,
    classes: ["highlighted"]
  }));
};
var processExtra = (extra, attrs) => {
  const result = [];
  if (extra === void 0)
    return result;
  extra.forEach((processor) => {
    const matched = processor.attrRe.exec(attrs);
    result.push({
      light: processor.light(matched),
      dark: processor.dark === null ? void 0 : (processor.dark || processor.light)(matched),
      position: processor.position
    });
  });
  return result;
};
var getStyleContent = (tag, regex) => {
  const match = regex.exec(tag);
  let style_content = "";
  if (match)
    style_content = match[1];
  return style_content;
};
var concatStyleAttrContent = (tag, regex, content) => {
  if (tag.match(regex))
    return tag.replace(regex, `$1$2$3;${content}$4`);
  else
    return tag.replace(NO_EXTRACT_RE, `$1 style="${content};"$2`);
};
var concatClassAttrContent = (tag, regex, content) => {
  if (tag.match(regex))
    return tag.replace(regex, `$1$2$3 ${content}$4`);
  else
    return tag.replace(NO_EXTRACT_RE, `$1 class="${content}"$2`);
};
var wrapFinalContainer = (light, dark = void 0, processedExtra = void 0) => {
  let prependResult = "";
  let appendResult = "";
  dark = dark || "";
  processedExtra = processedExtra || [];
  const light_style_content = getStyleContent(light, BACKGROUND_STYLE_RE);
  const dark_style_content = getStyleContent(dark, BACKGROUND_STYLE_RE);
  processedExtra.forEach((extra) => {
    let light2 = "";
    let dark2 = "";
    if (extra.light) {
      light2 = extra.light;
      light2 = concatStyleAttrContent(light2, EXTRACT_STYLE_RE, light_style_content);
      light2 = concatClassAttrContent(light2, EXTRACT_CLASS_RE, LIGHT_CLASS);
    }
    if (extra.dark) {
      dark2 = extra.dark;
      dark2 = concatStyleAttrContent(dark2, EXTRACT_STYLE_RE, dark_style_content);
      dark2 = concatClassAttrContent(dark2, EXTRACT_CLASS_RE, DARK_CLASS);
    }
    if (extra.position === 0 /* before */) {
      prependResult += light2;
      prependResult += dark2;
    } else {
      appendResult += light2;
      appendResult += dark2;
    }
  });
  return `<div class="shiki-container">${prependResult}${dark}${light}${appendResult}</div>`;
};
var MarkdownItShiki = (markdownit, options = {}) => {
  const _highlighter = options.highlighter;
  const {
    langs,
    themes,
    darkModeThemes,
    highlightLines,
    extra
  } = resolveOptions(options);
  let syncRun;
  if (!_highlighter) {
    const require2 = createRequire(import.meta.url);
    syncRun = createSyncFn(require2.resolve("./worker"));
    syncRun("getHighlighter", { langs, themes });
  }
  const highlightCode = (code, lang, theme, lineOptions) => {
    if (_highlighter)
      return _highlighter.codeToHtml(code, { lang: lang || "text", theme, lineOptions });
    return syncRun("codeToHtml", {
      code,
      theme,
      lang: lang || "text",
      lineOptions
    });
  };
  markdownit.options.highlight = (code, lang, attrs) => {
    let lineOptions;
    if (highlightLines) {
      const match = HIGHLIGHT_RE.exec(attrs);
      if (match)
        lineOptions = attrsToLines(match[1]);
    }
    const processedExtra = processExtra(extra, attrs);
    if (darkModeThemes) {
      const dark = highlightCode(code, lang, darkModeThemes.dark, lineOptions).replace('<pre class="shiki', `<pre class="shiki ${DARK_CLASS}`);
      const light = highlightCode(code, lang || "text", darkModeThemes.light, lineOptions).replace('<pre class="shiki', `<pre class="shiki ${LIGHT_CLASS}`);
      return wrapFinalContainer(light, dark, processedExtra);
    } else {
      return wrapFinalContainer(
        highlightCode(
          code,
          lang || "text",
          void 0,
          lineOptions
        ),
        void 0,
        processedExtra
      );
    }
  };
};
var src_default = MarkdownItShiki;

export {
  ExtraPosition,
  resolveOptions,
  src_default
};
