import { IThemeRegistration, ILanguageRegistration, Highlighter } from 'shiki';
import MarkdownIt from 'markdown-it';

interface DarkModeThemes {
    dark: IThemeRegistration;
    light: IThemeRegistration;
}
declare enum ExtraPosition {
    before = 0,
    after = 1
}
type Processor = (matched: RegExpExecArray | null) => string | undefined;
interface _LightOnlyProcessor {
    light: Processor;
    dark: null;
}
interface _LightDarkProcessor {
    light: Processor;
    dark?: Processor;
}
interface _IExtraProcessor {
    position: ExtraPosition;
    attrRe: RegExp;
}
type IExtraProcessor = (_IExtraProcessor & _LightOnlyProcessor) | (_IExtraProcessor & _LightDarkProcessor);
interface Options {
    theme?: IThemeRegistration | DarkModeThemes;
    langs?: ILanguageRegistration[];
    timeout?: number;
    highlighter?: Highlighter;
    highlightLines?: boolean;
    extra?: IExtraProcessor[];
}
declare function resolveOptions(options: Options): {
    themes: IThemeRegistration[];
    darkModeThemes: {
        dark: string;
        light: string;
    } | undefined;
    extra: IExtraProcessor[];
    theme?: DarkModeThemes | IThemeRegistration | undefined;
    langs?: ILanguageRegistration[] | undefined;
    timeout?: number | undefined;
    highlighter?: Highlighter | undefined;
    highlightLines?: boolean | undefined;
};
declare const MarkdownItShiki: MarkdownIt.PluginWithOptions<Options>;

export { DarkModeThemes, ExtraPosition, IExtraProcessor, Options, Processor, MarkdownItShiki as default, resolveOptions };
